# saxo

[![Build Status](https://travis-ci.org/sbp/saxo.png?branch=master)](https://travis-ci.org/sbp/saxo) [![PyPI version](https://badge.fury.io/py/saxo.png)](http://badge.fury.io/py/saxo)

Quick and flexible [irc bot](https://en.wikipedia.org/wiki/Internet_Relay_Chat_bot), extensible in any language.

## Quick start

You will need [Python](http://www.python.org/) 3.3 or later.

    git clone https://github.com/sbp/saxo.git
    cd saxo
    ./saxo create

Edit your `~/.saxo/config` file in a text editor. Then start the bot:

    ./saxo -f start

## Support

Ask in `#saxo` on [freenode](http://freenode.net/), or tweet [@sbp](https://twitter.com/sbp).

## Documentation

Try the [docs](docs) directory:

* [Getting started](docs/getting-started.md)
* [Saxo config](docs/config.md)
* [List of saxo commands](docs/commands.md)
* [Write saxo commands](docs/write-commands.md)
* [Changes](docs/changes.md)

## Credits

Thanks to Scott Arciszewski and many others!

## License

[Apache License](https://en.wikipedia.org/wiki/Apache_License) 2.0.
